DATA_CLIENT_LIVE = 0
DATA_CLIENT_1S = 1000
DATA_CLIENT_1M = DATA_CLIENT_1S * 60
DATA_CLIENT_1H = DATA_CLIENT_1M * 60

ports = {
    DATA_CLIENT_LIVE: "3550",
    DATA_CLIENT_1S: "3551",
    DATA_CLIENT_1M: "3552",
    DATA_CLIENT_1H: "3553",
}

FREQ_1S = 1000
FREQ_3S = 3000
FREQ_5S = 5000
FREQ_15S = 15000
FREQ_30S = 30000
FREQ_45S = 45000
FREQ_1M = 60000
FREQ_3M = 180000
FREQ_5M = 300000
FREQ_15M = 900000
FREQ_30M = 1800000
FREQ_45M = 2700000
FREQ_1H = 3600000
FREQ_2H = 7200000
FREQ_3H = 10800000
FREQ_4H = 14400000
FREQ_8H = 28800000
FREQ_12H = 43200000

FREQUENCIES = [
    FREQ_1S,
    FREQ_3S,
    FREQ_5S,
    FREQ_15S,
    FREQ_30S,
    FREQ_45S,
    FREQ_1M,
    FREQ_3M,
    FREQ_5M,
    FREQ_15M,
    FREQ_30M,
    FREQ_45M,
    FREQ_1H,
    FREQ_2H,
    FREQ_3H,
    FREQ_4H,
    FREQ_8H,
    FREQ_12H,
]
